@@ -1,8 +1,8 @@
 mod structs;
 mod traits;
-use crate::structs::cash::Cash;
-use crate::structs::cash::create::Procedures;
-use crate::structs::cash::calculate::Operations;
+use structs::cash::Cash;
+use traits::create::Procedures;
+use traits::calculate::Operations;
 
 fn cristi() {
     let wallet: Cash = Cash::create(String::from("eur"), 2);
